/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {useThunk} from '@liferay/frontend-js-react-web';
import PropTypes from 'prop-types';
import React, {useReducer} from 'react';

import {AppContext} from './AppContext';
import DataSet from './DataSet';
import ViewsContext, {viewsReducer} from './views/ViewsContext';

const FrontendDataSet = ({
	activeViewSettings,
	apiURL,
	appURL,
	customViewsEnabled,
	portletId,
	views,
	...props
}) => {
	const getInitialViewsState = () => {
		let initialActiveView = views[0];
		let initialVisibleFieldNames = {};

		if (activeViewSettings) {
			const {name, visibleFieldNames} = JSON.parse(activeViewSettings);

			if (name) {
				initialActiveView = views.find(
					({viewName}) => viewName === name
				);
			}

			if (visibleFieldNames) {
				initialVisibleFieldNames = visibleFieldNames;
			}
		}

		return {
			activeView: initialActiveView,
			customViewsEnabled,
			views,
			visibleFieldNames: initialVisibleFieldNames,
		};
	};

	const [state, dispatch] = useThunk(
		useReducer(viewsReducer, getInitialViewsState())
	);

	return (
		<AppContext.Provider value={{apiURL, appURL, portletId}}>
			<ViewsContext.Provider value={[state, dispatch]}>
				<DataSet {...props} />
			</ViewsContext.Provider>
		</AppContext.Provider>
	);
};

FrontendDataSet.proptypes = {
	activeViewSettings: PropTypes.shape({
		name: PropTypes.string,
		visibleFieldNames: PropTypes.array,
	}),
	apiURL: PropTypes.string,
	appURL: PropTypes.string,
	portletId: PropTypes.string,
	views: PropTypes.arrayOf(
		PropTypes.shape({
			component: PropTypes.any,
			contentRenderer: PropTypes.string,
			contentRendererModuleURL: PropTypes.string,
			label: PropTypes.string,
			schema: PropTypes.object,
			thumbnail: PropTypes.string,
		})
	).isRequired,
};

export default FrontendDataSet;
