/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import PropType from 'prop-types';

import {getValueFromItem} from '../utils/index';

function ListRenderer(props) {
	if (!props.value || props.value.length === 0) {
		return null;
	}
	if (props.options.singleItemLabel && props.value.length === 1) {
		return props.options.singleItemLabel;
	}
	if (props.options.multipleItemsLabel && props.value.length > 1) {
		return props.options.multipleItemsLabel;
	}

	return props.value
		.map((element) => getValueFromItem(element, props.options.labelKey))
		.join(props.options.separator || ', ');
}

ListRenderer.propTypes = {
	options: PropType.shape({
		labelKey: PropType.oneOfType([PropType.array, PropType.string])
			.isRequired,
		multipleItemsLabel: PropType.string,
		separator: PropType.string,
		singleItemLabel: PropType.string,
	}),
	value: PropType.array,
};

export default ListRenderer;
